@@ -1,5 +1,5 @@
 # Copyright 2019 Katteli Inc.
-# TestFlows Test Framework (http://testflows.com)
+# TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -30,7 +30,7 @@ def get(a, b):
 
 def hash(*s, short=False):
     """Calculate standard hash.
-    
+
     :param s: strings
     :param short: short version, default: False
     """
@@ -110,7 +110,11 @@ class Table(tuple, TestObject):
         obj.header = header
         obj.rows = obj
         obj.row_type = row_type
-        obj.row_format = get(row_format, Table.default_row_format(row_type._fields, obj[0] if obj else None))
+        if row_format:
+            row_format % tuple(obj.header.split(" "))
+        else:
+            row_format = Table.default_row_format(row_type._fields, obj[0] if obj else None)
+        obj.row_format = row_format
         return obj
 
     @staticmethod
@@ -144,4 +148,4 @@ class Table(tuple, TestObject):
     def from_table(cls, table):
         """Creates table from a table.
         """
-        return cls(header=" ".join(table.row_type._fields), rows=table, row_format=table.row_format)
\ No newline at end of file
+        return cls(header=" ".join(table.row_type._fields), rows=table, row_format=table.row_format)
