@@ -123,7 +123,7 @@ def format_result(msg):
     out = f"{_icon} "+ color_other(f"{strftimedelta(msg['message_rtime']):<10}") + f"[ {result.center(6, ' ')} ]".ljust(10, ' ').replace(result, _result)
 
     _result_message = msg["result_message"]
-    if _result_message and settings.trim and int(msg["test_level"]) > 1:
+    if _result_message and settings.trim_results and int(msg["test_level"]) > 1:
         _result_message = _result_message.strip().split("\n",1)[0].strip()
 
     if result in ("Fail", "Error", "Null"):
